pub enum AccountTransportActionKind {
Connect,
SendText,
ReceiveText,
Close,
}Expand description
One system effect Android executes for the active account transport.
Variants
Connect
Open the selected WebSocket, optionally after the bounded delay.
SendText
Send one complete ordered text frame.
ReceiveText
Wait for one complete incoming text frame or the bounded deadline.
Close
Close the current WebSocket.