pub enum PendingMediaMessageState {
WaitingForUploads,
ReadyToPublish,
Published,
Failed,
Cancelled,
}Expand description
Logical state of one attachment-dependent outgoing message.
Variants
WaitingForUploads
Durable message intent is waiting for one or more platform uploads.
ReadyToPublish
Every attachment completed and the message can be authored.
Published
The complete outgoing message operation was committed.
Failed
A required attachment failed permanently.
Cancelled
The user cancelled a required attachment before publication.