pub enum RelayRetryAction {
WaitSameRelay,
RotateRelay,
}Expand description
Retry/failover action selected by Rust.
Variants
WaitSameRelay
Retain the same relay and wait for the platform/network.
RotateRelay
Select the next effective relay immediately after the delay.