complete_external_event_signing

Function complete_external_event_signing 

pub fn complete_external_event_signing(
    request: ExternalEventSigningRequest,
    signature: String,
) -> Result<SignedEvent, SoftchatError>
Attach and verify a provider signature.

The request’s ID is recomputed and the resulting BIP-340 signature is verified before a signed event is returned.

Errors

Any malformed, mismatched, or unauthenticated provider signature maps to SoftchatError::InvalidExternalSignature.