pub struct AccountOperationResult {
pub operation: OperationSnapshot,
pub revision: i64,
pub inserted: bool,
}Expand description
Result of an idempotent outgoing operation transaction.
Fields
operation: OperationSnapshotCurrent aggregate operation state.
revision: i64Database revision after commit, or the current revision for a replay.
inserted: boolWhether this call inserted the operation for the first time.