pub struct FollowListView {
pub rumor: RumorEvent,
pub contacts: Vec<Contact>,
pub contained_duplicates: bool,
}Expand description
Typed private kind-3 contact backup.
Fields
rumor: RumorEventComplete exact source rumor.
contacts: Vec<Contact>First occurrence of each public key, sorted by public key.
contained_duplicates: boolWhether duplicate received contacts were ignored for the typed view.