pub struct NegentropyStep {
pub outgoing: Option<Vec<u8>>,
pub have_event_ids: Vec<String>,
pub need_event_ids: Vec<String>,
pub complete: bool,
}Expand description
Result of one stateful client reconciliation step.
Fields
outgoing: Option<Vec<u8>>Next binary query to send, absent when reconciliation is complete.
have_event_ids: Vec<String>IDs present locally and absent remotely in this step.
need_event_ids: Vec<String>IDs absent locally and present remotely in this step.
complete: boolWhether no further protocol frame is needed.