NostrTag

Struct NostrTag 

pub struct NostrTag { /* private fields */ }
One exact, non-empty NIP-01 tag array.

Implementations

Source

impl NostrTag

pub fn new<I, S>(values: I) -> Result<Self, SoftchatError>
where I: IntoIterator<Item = S>, S: Into<String>,

Retain one raw tag without interpreting or normalizing its elements.

Empty strings and trailing empty elements are significant and remain unchanged.

Errors

Returns SoftchatError::InvalidEventTag for an empty array.

pub fn values(&self) -> &[String]

Borrow every raw string in this tag, including trailing empty values.