pub fn project_chat_message(
original: RumorEvent,
edits: Vec<RumorEvent>,
deletions: Vec<RumorEvent>,
) -> Result<MessageProjection, SoftchatError>Expand description
Apply authorized edit and deletion history without owning persistence.
Errors
Returns SoftchatError::InvalidSoftchatProjection when any supplied
history event is malformed, targets another original, or has an
unauthorized author.